==> haskell-tagsoup-0.14-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tagsoup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tagsoup
version: 0.14
id: tagsoup-0.14-Cyor6HaGaUK6jsf16bXCqB
key: tagsoup-0.14-Cyor6HaGaUK6jsf16bXCqB
license: BSD3
copyright: Neil Mitchell 2006-2016
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/tagsoup#readme
synopsis: Parsing and extracting information from (possibly malformed) HTML/XML documents
description:
    TagSoup is a library for parsing HTML/XML. It supports the HTML 5 specification,
    and can be used to parse either well-formed XML, or unstructured and malformed HTML
    from the web. The library also provides useful functions to extract information
    from an HTML document, making it ideal for screen-scraping.
    .
    Users should start from the "Text.HTML.TagSoup" module.
category: XML
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    Text.HTML.TagSoup Text.HTML.TagSoup.Entity Text.HTML.TagSoup.Match
    Text.HTML.TagSoup.Tree Text.StringLike
hidden-modules: Text.HTML.TagSoup.Generated
                Text.HTML.TagSoup.Implementation Text.HTML.TagSoup.Manual
                Text.HTML.TagSoup.Options Text.HTML.TagSoup.Parser
                Text.HTML.TagSoup.Render Text.HTML.TagSoup.Specification
                Text.HTML.TagSoup.Type
abi: a1fdea8c23cca887402b13b0abd4348f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/tagsoup-0.14
library-dirs: /usr/lib/ghc-8.0.1/site-local/tagsoup-0.14
data-dir: /usr/share/i386-linux-ghc-8.0.1/tagsoup-0.14
hs-libraries: HStagsoup-0.14-Cyor6HaGaUK6jsf16bXCqB
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-tagsoup/html/tagsoup.haddock
haddock-html: /usr/share/doc/haskell-tagsoup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tagsoup-0.14.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tagsoup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tagsoup
version: 0.14.1
id: tagsoup-0.14.1-5UpYkVoOhOt4iyOyy0sWwj
key: tagsoup-0.14.1-5UpYkVoOhOt4iyOyy0sWwj
license: BSD3
copyright: Neil Mitchell 2006-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/tagsoup#readme
synopsis: Parsing and extracting information from (possibly malformed) HTML/XML documents
description:
    TagSoup is a library for parsing HTML/XML. It supports the HTML 5 specification,
    and can be used to parse either well-formed XML, or unstructured and malformed HTML
    from the web. The library also provides useful functions to extract information
    from an HTML document, making it ideal for screen-scraping.
    .
    Users should start from the "Text.HTML.TagSoup" module.
category: XML
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    Text.HTML.TagSoup Text.HTML.TagSoup.Entity Text.HTML.TagSoup.Match
    Text.HTML.TagSoup.Tree Text.StringLike
hidden-modules: Text.HTML.TagSoup.Generated
                Text.HTML.TagSoup.Implementation Text.HTML.TagSoup.Manual
                Text.HTML.TagSoup.Options Text.HTML.TagSoup.Parser
                Text.HTML.TagSoup.Render Text.HTML.TagSoup.Specification
                Text.HTML.TagSoup.Type
abi: e45c54a4e821751cd2d5610944b5f9d1
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/tagsoup-0.14.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/tagsoup-0.14.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/tagsoup-0.14.1
hs-libraries: HStagsoup-0.14.1-5UpYkVoOhOt4iyOyy0sWwj
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
haddock-interfaces: /usr/share/doc/haskell-tagsoup/html/tagsoup.haddock
haddock-html: /usr/share/doc/haskell-tagsoup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
